aboutsummaryrefslogtreecommitdiff
path: root/include/libssh/poll.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/libssh/poll.h')
-rw-r--r--include/libssh/poll.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/include/libssh/poll.h b/include/libssh/poll.h
index ab00139f..29512450 100644
--- a/include/libssh/poll.h
+++ b/include/libssh/poll.h
@@ -81,7 +81,8 @@ typedef struct ssh_poll_ctx_struct *ssh_poll_ctx;
typedef struct ssh_poll_handle_struct *ssh_poll_handle;
/**
* @brief SSH poll callback.
*
* @param p Poll object this callback belongs to.
* @param fd The raw socket.
@@ -89,9 +90,9 @@ typedef struct ssh_poll_handle_struct *ssh_poll_handle;
* @param userdata Userdata to be passed to the callback function.
*
* @return 0 on success, < 0 if you removed the poll object from
- * it's poll context.
+ * its poll context.
*/
-typedef int (*ssh_poll_callback)(ssh_poll_handle p, int fd, int revents,
+typedef int (*ssh_poll_callback)(ssh_poll_handle p, socket_t fd, int revents,
void *userdata);
@@ -81,7 +81,8 @@ typedef struct ssh_poll_ctx_struct *ssh_poll_ctx;
typedef struct ssh_poll_handle_struct *ssh_poll_handle;
/**
- * @brief SSH poll callback.
+ * @brief SSH poll callback. This callback will be used when an event
+ * caught on the socket.
*
* @param p Poll object this callback belongs to.